Box2D
Safe HaskellNone
LanguageGHC2021

Box2D.WheelJoint

Synopsis

Documentation

create :: WorldId -> WheelJointDef -> IO JointId Source #

Create a wheel joint See also b2WheelJointDef for details.

Binds b2CreateWheelJoint.

enableSpring Source #

Arguments

:: JointId 
-> Bool
enableSpring
-> IO () 

Enable/disable the wheel joint spring

Binds b2WheelJoint_EnableSpring.

isSpringEnabled :: JointId -> IO Bool Source #

Is the wheel joint spring enabled?

Binds b2WheelJoint_IsSpringEnabled.

setSpringHertz Source #

Arguments

:: JointId 
-> Float
hertz
-> IO () 

Set the wheel joint stiffness in Hertz

Binds b2WheelJoint_SetSpringHertz.

getSpringHertz :: JointId -> IO Float Source #

Get the wheel joint stiffness in Hertz

Binds b2WheelJoint_GetSpringHertz.

setSpringDampingRatio Source #

Arguments

:: JointId 
-> Float
dampingRatio
-> IO () 

Set the wheel joint damping ratio, non-dimensional

Binds b2WheelJoint_SetSpringDampingRatio.

getSpringDampingRatio :: JointId -> IO Float Source #

Get the wheel joint damping ratio, non-dimensional

Binds b2WheelJoint_GetSpringDampingRatio.

enableLimit Source #

Arguments

:: JointId 
-> Bool
enableLimit
-> IO () 

Enable/disable the wheel joint limit

Binds b2WheelJoint_EnableLimit.

isLimitEnabled :: JointId -> IO Bool Source #

Is the wheel joint limit enabled?

Binds b2WheelJoint_IsLimitEnabled.

getLowerLimit :: JointId -> IO Float Source #

Get the wheel joint lower limit

Binds b2WheelJoint_GetLowerLimit.

getUpperLimit :: JointId -> IO Float Source #

Get the wheel joint upper limit

Binds b2WheelJoint_GetUpperLimit.

setLimits Source #

Arguments

:: JointId 
-> Float
lower
-> Float
upper
-> IO () 

Set the wheel joint limits

Binds b2WheelJoint_SetLimits.

enableMotor Source #

Arguments

:: JointId 
-> Bool
enableMotor
-> IO () 

Enable/disable the wheel joint motor

Binds b2WheelJoint_EnableMotor.

isMotorEnabled :: JointId -> IO Bool Source #

Is the wheel joint motor enabled?

Binds b2WheelJoint_IsMotorEnabled.

setMotorSpeed Source #

Arguments

:: JointId 
-> Float
motorSpeed
-> IO () 

Set the wheel joint motor speed in radians per second

Binds b2WheelJoint_SetMotorSpeed.

getMotorSpeed :: JointId -> IO Float Source #

Get the wheel joint motor speed in radians per second

Binds b2WheelJoint_GetMotorSpeed.

setMaxMotorTorque Source #

Arguments

:: JointId 
-> Float
torque
-> IO () 

Set the wheel joint maximum motor torque, usually in newton-meters

Binds b2WheelJoint_SetMaxMotorTorque.

getMaxMotorTorque :: JointId -> IO Float Source #

Get the wheel joint maximum motor torque, usually in newton-meters

Binds b2WheelJoint_GetMaxMotorTorque.

getMotorTorque :: JointId -> IO Float Source #

Get the wheel joint current motor torque, usually in newton-meters

Binds b2WheelJoint_GetMotorTorque.