| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Box2D.WheelJoint
Synopsis
- create :: WorldId -> WheelJointDef -> IO JointId
- enableSpring :: JointId -> Bool -> IO ()
- isSpringEnabled :: JointId -> IO Bool
- setSpringHertz :: JointId -> Float -> IO ()
- getSpringHertz :: JointId -> IO Float
- setSpringDampingRatio :: JointId -> Float -> IO ()
- getSpringDampingRatio :: JointId -> IO Float
- enableLimit :: JointId -> Bool -> IO ()
- isLimitEnabled :: JointId -> IO Bool
- getLowerLimit :: JointId -> IO Float
- getUpperLimit :: JointId -> IO Float
- setLimits :: JointId -> Float -> Float -> IO ()
- enableMotor :: JointId -> Bool -> IO ()
- isMotorEnabled :: JointId -> IO Bool
- setMotorSpeed :: JointId -> Float -> IO ()
- getMotorSpeed :: JointId -> IO Float
- setMaxMotorTorque :: JointId -> Float -> IO ()
- getMaxMotorTorque :: JointId -> IO Float
- getMotorTorque :: JointId -> IO Float
Documentation
create :: WorldId -> WheelJointDef -> IO JointId Source #
Create a wheel joint See also b2WheelJointDef for details.
Binds b2CreateWheelJoint.
Enable/disable the wheel joint spring
Binds b2WheelJoint_EnableSpring.
isSpringEnabled :: JointId -> IO Bool Source #
Is the wheel joint spring enabled?
Binds b2WheelJoint_IsSpringEnabled.
Set the wheel joint stiffness in Hertz
Binds b2WheelJoint_SetSpringHertz.
getSpringHertz :: JointId -> IO Float Source #
Get the wheel joint stiffness in Hertz
Binds b2WheelJoint_GetSpringHertz.
setSpringDampingRatio Source #
Set the wheel joint damping ratio, non-dimensional
Binds b2WheelJoint_SetSpringDampingRatio.
getSpringDampingRatio :: JointId -> IO Float Source #
Get the wheel joint damping ratio, non-dimensional
Binds b2WheelJoint_GetSpringDampingRatio.
Enable/disable the wheel joint limit
Binds b2WheelJoint_EnableLimit.
isLimitEnabled :: JointId -> IO Bool Source #
Is the wheel joint limit enabled?
Binds b2WheelJoint_IsLimitEnabled.
getLowerLimit :: JointId -> IO Float Source #
Get the wheel joint lower limit
Binds b2WheelJoint_GetLowerLimit.
getUpperLimit :: JointId -> IO Float Source #
Get the wheel joint upper limit
Binds b2WheelJoint_GetUpperLimit.
Set the wheel joint limits
Binds b2WheelJoint_SetLimits.
Enable/disable the wheel joint motor
Binds b2WheelJoint_EnableMotor.
isMotorEnabled :: JointId -> IO Bool Source #
Is the wheel joint motor enabled?
Binds b2WheelJoint_IsMotorEnabled.
Set the wheel joint motor speed in radians per second
Binds b2WheelJoint_SetMotorSpeed.
getMotorSpeed :: JointId -> IO Float Source #
Get the wheel joint motor speed in radians per second
Binds b2WheelJoint_GetMotorSpeed.
Set the wheel joint maximum motor torque, usually in newton-meters
Binds b2WheelJoint_SetMaxMotorTorque.